==> mariadb-connector-java_2.3.0.orig.tar.xz: mariadb-connector-j-2.3.0/src/test/java/org/mariadb/jdbc/internal/util/buffer/BufferTest.java <==
/*
 *
 * MariaDB Client for Java
 *
 * Copyright (c) 2012-2014 Monty Program Ab.
 * Copyright (c) 2015-2017 MariaDB Ab.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
 * for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along
 * with this library; if not, write to Monty Program Ab info@montyprogram.com.
 *
 * This particular MariaDB Client for Java file is work
 * derived from a Drizzle-JDBC. Drizzle-JDBC file which is covered by subject to
 * the following copyright and notice provisions:
 *
 * Copyright (c) 2009-2011, Marcus Eriksson
 *
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * Redistributions of source code must retain the above copyright notice, this list
 * of conditions and the following disclaimer.
 *
 * Redistributions in binary form must reproduce the above copyright notice, this
 * list of conditions and the following disclaimer in the documentation and/or
 * other materials provided with the distribution.
 *
 * Neither the name of the driver nor the names of its contributors may not be
 * used to endorse or promote products derived from this software without specific
 * prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS  AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY
 * OF SUCH DAMAGE.
 *
 */

package org.mariadb.jdbc.internal.util.buffer;

import org.junit.Assert;
import org.junit.Test;
import org.mariadb.jdbc.internal.com.read.Buffer;

public class BufferTest {

  @Test
  public void testGetLengthEncodedBinary() throws Exception {
    Assert.assertEquals(15, new Buffer(new byte[]{(byte) 0x0f}).getLengthEncodedNumeric());
    Assert.assertEquals(65535,
        new Buffer(new byte[]{(byte) 0xfc, (byte) 0xff, (byte) 0xff}).getLengthEncodedNumeric());
    Assert.assertEquals(16777215,
        new Buffer(new byte[]{(byte) 0xfd, (byte) 0xff, (byte) 0xff, (byte) 0xff})
            .getLengthEncodedNumeric());
    Assert.assertEquals(Long.MAX_VALUE, new Buffer(
        new byte[]{(byte) 0xfe, (byte) 0xff, (byte) 0xff, (byte) 0xff, (byte) 0xff, (byte) 0xff,
            (byte) 0xff, (byte) 0xff, (byte) 0x7f}).getLengthEncodedNumeric());
  }

  @Test
  public void testSkipLengthEncodedBytes() throws Exception {
    byte[] arr15 = new byte[1];
    arr15[0] = (byte) 0x0f;
    Buffer buf15 = new Buffer(arr15);
    buf15.skipLengthEncodedBytes();
    Assert.assertEquals(16, buf15.position);

    byte[] arr2 = new byte[3];
    arr2[0] = (byte) 0xfc;
    arr2[1] = (byte) 0xff;
    arr2[2] = (byte) 0xff;
    Buffer buf2 = new Buffer(arr2);
    buf2.skipLengthEncodedBytes();
    Assert.assertEquals(65538, buf2.position);

    byte[] arr3 = new byte[4];
    arr3[0] = (byte) 0xfd;
    arr3[1] = (byte) 0xff;
    arr3[2] = (byte) 0xff;
    arr3[3] = (byte) 0xff;
    Buffer buf3 = new Buffer(arr3);
    buf3.skipLengthEncodedBytes();
    Assert.assertEquals(16777215 + 4, buf3.position);

    byte[] arr4 = new byte[9];
    arr4[0] = (byte) 0xfe;
    arr4[1] = (byte) 0xf0;
    arr4[2] = (byte) 0xff;
    arr4[3] = (byte) 0xff;
    arr4[4] = (byte) 0x7f;
    arr4[5] = (byte) 0x00;
    arr4[6] = (byte) 0x00;
    arr4[7] = (byte) 0x00;
    arr4[8] = (byte) 0x00;
    Buffer buf4 = new Buffer(arr4);
    buf4.skipLengthEncodedBytes();
    Assert.assertEquals(Integer.MAX_VALUE - 15 + 9, buf4.position);

  }

}

==> mariadb-connector-java_2.4.2.orig.tar.xz: mariadb-connector-j-2.4.2/src/test/java/org/mariadb/jdbc/internal/util/buffer/BufferTest.java <==
/*
 *
 * MariaDB Client for Java
 *
 * Copyright (c) 2012-2014 Monty Program Ab.
 * Copyright (c) 2015-2017 MariaDB Ab.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
 * for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along
 * with this library; if not, write to Monty Program Ab info@montyprogram.com.
 *
 * This particular MariaDB Client for Java file is work
 * derived from a Drizzle-JDBC. Drizzle-JDBC file which is covered by subject to
 * the following copyright and notice provisions:
 *
 * Copyright (c) 2009-2011, Marcus Eriksson
 *
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * Redistributions of source code must retain the above copyright notice, this list
 * of conditions and the following disclaimer.
 *
 * Redistributions in binary form must reproduce the above copyright notice, this
 * list of conditions and the following disclaimer in the documentation and/or
 * other materials provided with the distribution.
 *
 * Neither the name of the driver nor the names of its contributors may not be
 * used to endorse or promote products derived from this software without specific
 * prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS  AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY
 * OF SUCH DAMAGE.
 *
 */

package org.mariadb.jdbc.internal.util.buffer;

import org.junit.Assert;
import org.junit.Test;
import org.mariadb.jdbc.internal.com.read.Buffer;

public class BufferTest {

  @Test
  public void testGetLengthEncodedBinary() {
    Assert.assertEquals(15, new Buffer(new byte[]{(byte) 0x0f}).getLengthEncodedNumeric());
    Assert.assertEquals(65535,
        new Buffer(new byte[]{(byte) 0xfc, (byte) 0xff, (byte) 0xff}).getLengthEncodedNumeric());
    Assert.assertEquals(16777215,
        new Buffer(new byte[]{(byte) 0xfd, (byte) 0xff, (byte) 0xff, (byte) 0xff})
            .getLengthEncodedNumeric());
    Assert.assertEquals(Long.MAX_VALUE, new Buffer(
        new byte[]{(byte) 0xfe, (byte) 0xff, (byte) 0xff, (byte) 0xff, (byte) 0xff, (byte) 0xff,
            (byte) 0xff, (byte) 0xff, (byte) 0x7f}).getLengthEncodedNumeric());
  }

  @Test
  public void testSkipLengthEncodedBytes() {
    byte[] arr15 = new byte[1];
    arr15[0] = (byte) 0x0f;
    Buffer buf15 = new Buffer(arr15);
    buf15.skipLengthEncodedBytes();
    Assert.assertEquals(16, buf15.position);

    byte[] arr2 = new byte[3];
    arr2[0] = (byte) 0xfc;
    arr2[1] = (byte) 0xff;
    arr2[2] = (byte) 0xff;
    Buffer buf2 = new Buffer(arr2);
    buf2.skipLengthEncodedBytes();
    Assert.assertEquals(65538, buf2.position);

    byte[] arr3 = new byte[4];
    arr3[0] = (byte) 0xfd;
    arr3[1] = (byte) 0xff;
    arr3[2] = (byte) 0xff;
    arr3[3] = (byte) 0xff;
    Buffer buf3 = new Buffer(arr3);
    buf3.skipLengthEncodedBytes();
    Assert.assertEquals(16777215 + 4, buf3.position);

    byte[] arr4 = new byte[9];
    arr4[0] = (byte) 0xfe;
    arr4[1] = (byte) 0xf0;
    arr4[2] = (byte) 0xff;
    arr4[3] = (byte) 0xff;
    arr4[4] = (byte) 0x7f;
    arr4[5] = (byte) 0x00;
    arr4[6] = (byte) 0x00;
    arr4[7] = (byte) 0x00;
    arr4[8] = (byte) 0x00;
    Buffer buf4 = new Buffer(arr4);
    buf4.skipLengthEncodedBytes();
    Assert.assertEquals(Integer.MAX_VALUE - 15 + 9, buf4.position);

  }

}
